@@ -8,8 +8,7 @@ from gym import spaces
 from rtgym.envs.real_time_env import DEFAULT_CONFIG_DICT
 
 # local imports
-from tmrl.custom.custom_gym_interfaces import (TM2020Interface, TM2020InterfaceLidar,
-                                               TMInterface, TMInterfaceLidar)
+from tmrl.custom.custom_gym_interfaces import (TM2020Interface, TM2020InterfaceLidar)
 import logging
 
 NB_STEPS = 1000
